summaryrefslogtreecommitdiffstats
path: root/parameter/ParameterType.h
diff options
context:
space:
mode:
authorPatrick Benavoli <patrickx.benavoli@intel.com>2011-08-31 11:23:24 +0200
committerDavid Wagner <david.wagner@intel.com>2014-02-10 17:14:54 +0100
commit1387bda01b089d8e8df06339d9c15d53b3de6725 (patch)
treec8dd258fdff344e629433f89976ca573ff828c31 /parameter/ParameterType.h
parent2ecf900ad8c30ce9f8e81f57977a1a80a6f6d8af (diff)
downloadexternal_parameter-framework-1387bda01b089d8e8df06339d9c15d53b3de6725.zip
external_parameter-framework-1387bda01b089d8e8df06339d9c15d53b3de6725.tar.gz
external_parameter-framework-1387bda01b089d8e8df06339d9c15d53b3de6725.tar.bz2
Min/max value computation; Tuning lock handling
BZ: 7466 - Min/max values are now correctly computed. They concern integer and fixed point parameters - tuning mode lock issue solved: created an AutoLock class for safe lock handling - added configuration files for a demo on Ubuntu environment - had AMIXER subsystem plugin compliant for derivation - LPE library: add carriage return on logs - removed obsolete files - some cosmetics Change-Id: Ife7a4799fd48dd4a1ca25dae666c4e453815881e Orig-Change-Id: I72fc5c1ff6abf638b43266a75bc00e21ad412349 Signed-off-by: Patrick Benavoli <patrickx.benavoli@intel.com> Reviewed-on: http://android.intel.com:8080/16880 Reviewed-by: Mahe, Erwan <erwan.mahe@intel.com> Tested-by: Barthes, FabienX <fabienx.barthes@intel.com> Reviewed-by: buildbot <buildbot@intel.com> Tested-by: buildbot <buildbot@intel.com>
Diffstat (limited to 'parameter/ParameterType.h')
-rw-r--r--parameter/ParameterType.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/parameter/ParameterType.h b/parameter/ParameterType.h
index 88ee0ea..980afba 100644
--- a/parameter/ParameterType.h
+++ b/parameter/ParameterType.h
@@ -70,12 +70,12 @@ protected:
void setSize(uint32_t uiSize);
// Sign extension
void signExtend(int32_t& iData) const;
// Check data has no bit set outside available range
bool isEncodable(uint32_t uiData) const;
+ // Check data has no bit set outside available range
+ bool isEncodable(uint32_t uiData, uint32_t uiSizeInBits) const;
// Remove all bits set outside available range
uint32_t makeEncodable(uint32_t uiData) const;
- // Check data is consistent with available range, with respect to its sign
- bool isConsistent(uint32_t uiData, bool bSigned) const;
private:
// Instantiation
@@ -70,12 +70,12 @@ protected:
// Sign extension
void signExtend(int32_t& iData) const;
- // Check data has no bit set outside available range
+ // Check data has no bit set outside available range (based on byte size)
bool isEncodable(uint32_t uiData) const;